@@ -72,6 +72,9 @@ class AMQPData(GeneralData):
                     durable=self.durable, 
                     arguments={'x-message-ttl' : self.ttl})
                 self.channel.queue_bind(self.queue_name, self.exchange, self.routing_key)
+            else:
+                self.queue_name = self.channel.queue_declare(exclusive=True)[0]
+                self.channel.queue_bind(self.queue_name, exchange=self.exchange)
         except Exception as e:
             self.logger.exception("Error declaring queue -> %s" % e)
             self.connected = False
